
# get directory of samples
inpath = paste(script.dir,"/data/","corals1",sep="")
D1 = list.files(paste(inpath))

# pre-allocate
expNames = vector(,length(D1))
fwhm_v1_means = vector(,length(D1))
fwhm_v1_std = vector(,length(D1))
fwhm_v1_se = vector(,length(D1))
peak_v1_means = vector(,length(D1))
peak_v1_std = vector(,length(D1))
peak_v1_se = vector(,length(D1))
pos_v1_means = vector(,length(D1))
pos_v1_std = vector(,length(D1))
pos_v1_se = vector(,length(D1))
bg_means = vector(,length(D1))
bg_std = vector(,length(D1))
bg_se = vector(,length(D1))
omega_coral_means = vector(,length(D1))
omega_coral_std = vector(,length(D1))
omega_coral_se = vector(,length(D1))
co2 = vector(,length(D1))
time = vector(,length(D1))
fwhm_v1_weighted = vector(,length(D1))
pos_v1_weighted = vector(,length(D1))
n_good = vector(,length(D1))
omega_coral_means_weighted = vector(,length(D1))
omega_coral_std_weighted = vector(,length(D1))
omega_coral_se_weighted = vector(,length(D1))
speciesInds = vector(,length(D1))
tankInds = vector(,length(D1))
individualInds = vector(,length(D1))
analysisInds = vector(,length(D1))

# load the metadata
metadata = read.table(paste(script.dir,"/data/","metadata.csv",sep=""),header=TRUE,sep=',',stringsAsFactors = FALSE)

# set limits to exclude erroneous spectra (needed to remove spectra that missed sample and to remove spectra contaminated by cosmic rays)
peakLim = 50 # minimum signal
posLim = 1085 # minimum wavenumber
bgLim = 1000 # maximum background
fwhmMin = 2.7 # minimum width
fwhmMax = 4.5 # maximum width

# loop to calculate curve parameters for each spectra
for (ii in 1:1:length(D1)) {

# get files within this individual folder (for these analyses, all have only 1 file)
D = D1[ii]
n = 100 # number of spectra per time series

# read the name of the tank and the species
ch1 = strsplit(D,"_")
speciesInds[ii] = ch1[[1]][1]
individualInds[ii] = (ch1[[1]][2])
analysisInds[ii] = as.numeric(ch1[[1]][3])

# run the curve fitting routine
source(paste(script.dir,"/code/","Raman_calcs_biogenic.R",sep=""))

# sync to metadata
if (length(which(metadata$ID %in% individualInds[ii]))>0){
expInds = which(metadata$ID %in% individualInds[ii])
co2[ii] = metadata$CO2[expInds]
time[ii] = metadata$Time[expInds]
}

# remove data in which curves were not fit (generally spots that missed the samples)
fwhm_v1 = fwhm_v1[which(bg!="NA")]
peak_v1 = peak_v1[which(bg!="NA")]
pos_v1 = pos_v1[which(bg!="NA")]
bg = bg[which(bg!="NA")]

# calculate means, standard deviations, and standard errors for curve parameters, applying the filtering criteria listed above to remove erroneous spectra
fwhm_v1_means[ii] = mean(fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
fwhm_v1_std[ii] = sd(fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
fwhm_v1_se[ii] = sd(fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

peak_v1_means[ii] = mean(peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
peak_v1_std[ii] = sd(peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
peak_v1_se[ii] = sd(peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

pos_v1_means[ii] = mean(pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
pos_v1_std[ii] = sd(pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
pos_v1_se[ii] = sd(pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

bg_means[ii] = mean(bg[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
bg_std[ii] = sd(bg[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])
bg_se[ii] = sd(bg[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

# weight by peak height (i.e. more intensity means better quality data)
goodPeak = peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)]
goodPos = pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)]
goodFwhm = fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posLim & peak_v1>peakLim & bg<bgLim)]
weights = goodPeak/sum(goodPeak)
pos_v1_weighted[ii] = sum(weights*goodPos)
fwhm_v1_weighted[ii] = sum(weights*goodFwhm)

# record number of useful spectra
n_good[ii] = length(goodPeak)

}

jcp_adjustment = 0 # done below

# JCP-1 correction
jcp_trend1 = approx(x = analysisInds[which(speciesInds=="JCP")], y = fwhm_v1_means[which(speciesInds=="JCP")], xout = analysisInds)
fwhm_v1_means0 = fwhm_v1_means
fwhm_v1_means = fwhm_v1_means-jcp_trend1$y+3.52

jcp_trend2 = approx(x = analysisInds[which(speciesInds=="JCP")], y = fwhm_v1_weighted[which(speciesInds=="JCP")], xout = analysisInds)
fwhm_v1_weighted0 = fwhm_v1_weighted
fwhm_v1_weighted = fwhm_v1_weighted-jcp_trend2$y+3.52

omega_original = exp((fwhm_v1_weighted0-2.09)/0.57)
omega_corrected = exp((fwhm_v1_weighted-2.09)/0.57)
jcp_dif = omega_corrected-omega_original

# set limit of good spectra
inds = which(n_good>3)

# remove missing samples
fwhm_v1_weighted = fwhm_v1_weighted[inds]
omega_coral_means_weighted = exp((fwhm_v1_weighted-2.09)/0.57) + jcp_adjustment
pos_v1_weighted = pos_v1_weighted[inds]
fwhm_v1_means = fwhm_v1_means[inds]
omega_coral_means = exp((fwhm_v1_means-2.09)/0.57) + jcp_adjustment
fwhm_v1_std = fwhm_v1_std[inds]
fwhm_v1_se = fwhm_v1_se[inds]
peak_v1_means = peak_v1_means[inds]
peak_v1_std = peak_v1_std[inds]
peak_v1_se = peak_v1_se[inds]
pos_v1_means = pos_v1_means[inds]
pos_v1_std = pos_v1_std[inds]
pos_v1_se = pos_v1_se[inds]
bg_means = bg_means[inds]
bg_std = bg_std[inds]
bg_se = bg_se[inds]
individualInds = individualInds[inds]
speciesInds = speciesInds[inds]
co2 = co2[inds]
time = time[inds]
n_good = n_good[inds]

co2[which(speciesInds=="JCP")] = NA
time[which(speciesInds=="JCP")] = NA

speciesInds[which(speciesInds=="acr")] = "Acropora"
speciesInds[which(speciesInds=="por")] = "Porites"
speciesInds[which(speciesInds=="JCP")] = "JCP"

# sort for output
ord1 = order(speciesInds)
ord1a = ord1[which(speciesInds[ord1]=="Acropora")]
ord1b = ord1[which(speciesInds[ord1]=="Porites")]
ord1c = ord1[which(speciesInds[ord1]=="JCP")]
ord2a = ord1a[order(individualInds[ord1a])]
ord2b = ord1b[order(individualInds[ord1b])]
ord2c = ord1c[order(individualInds[ord1c])]
ord = c(ord2a,ord2b,ord2c)

# output data

data_out = data.frame(speciesInds[ord], co2[ord], time[ord], individualInds[ord],  omega_coral_means_weighted[ord], fwhm_v1_weighted[ord], fwhm_v1_se[ord], pos_v1_weighted[ord], pos_v1_se[ord], n_good[ord])
colnames(data_out) = c("species", "CO2", "Time point", "individual number", "Raman-derived Omega" ,"FWHM (1/cm)", "FWHM standard error", "raw wavenumber (1/cm)", "wavenumber standard error", "number of good spectra")
write.csv(data_out,file=paste(script.dir,"/output/","Moorea_coral_output1.csv",sep=""), row.names=FALSE)


